@@ -4,6 +4,10 @@
 #include <stdlib.h>
 #include <assert.h>
 
+#ifndef BOOL 
+#define BOOL int
+#endif
+
 #ifndef TRUE
 #define TRUE 1
 #endif
@@ -13,11 +17,11 @@
 #endif
 
 #ifndef ALLOC
-#define ALLOC                   // indicate that a memory should be freed after using
+#define ALLOC                   // indicated this memory should be freed after used
 #endif
 
 #ifndef MANAGED
-#define MANAGED                 // indicate that a memory is managed inside the function or object
+#define MANAGED                 // indicated this memory is managed inside the function or object
 #endif
 
 #if !defined(MDEBUG)
@@ -25,9 +29,13 @@
 #   define CHECKML_BEGIN()
 #   define CHECKML_END()
 
-#   define MALLOC(o) malloc(o)
-#   define STRDUP(o) strdup(o)
-#   define REALLOC(o, o2) realloc(o, o2)
+ALLOC void* xmalloc(size_t size);
+ALLOC char* xstrdup(char* str);
+ALLOC void* xrealloc(void* ptr, size_t size);
+
+#   define MALLOC(o) xmalloc(o)
+#   define STRDUP(o) xstrdup(o)
+#   define REALLOC(o, o2) xrealloc(o, o2)
 #   define FREE(o) free(o)
 
 #   define ASSERT(o)
