@@ -63,7 +63,7 @@ BOOL get_object_from_argument(sObject** object, char* str, sObject* current_obje
                     *object = gRootObject;
                 }
                 else {
-                    err_msg("invalid object name2", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("invalid object name2", runinfo->mSName, runinfo->mSLine);
                     return FALSE;
                 }
             }
@@ -74,7 +74,7 @@ BOOL get_object_from_argument(sObject** object, char* str, sObject* current_obje
                     *object = access_object(string_c_str(name), &current_object, running_object);
 
                     if(*object == NULL || STYPE(*object) != T_UOBJECT) {
-                        err_msg("invalid object name2", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("invalid object name2", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
                 }
@@ -82,7 +82,7 @@ BOOL get_object_from_argument(sObject** object, char* str, sObject* current_obje
                     *object = uobject_item(*object, string_c_str(name));
 
                     if(*object == NULL || STYPE(*object) != T_UOBJECT) {
-                        err_msg("invalid object name3", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("invalid object name3", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
                 }
@@ -106,7 +106,7 @@ BOOL get_object_from_argument(sObject** object, char* str, sObject* current_obje
     }
 
     if(*object == NULL) {
-        err_msg("invalid object name4", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("invalid object name4", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -130,7 +130,7 @@ BOOL get_object_prefix_and_name_from_argument(sObject** object, sObject* name, c
                     *object = gRootObject;
                 }
                 else {
-                    err_msg("invalid object name5", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("invalid object name5", runinfo->mSName, runinfo->mSLine);
                     return FALSE;
                 }
             }
@@ -141,7 +141,7 @@ BOOL get_object_prefix_and_name_from_argument(sObject** object, sObject* name, c
                     *object = access_object(string_c_str(name), &current_object, running_object);
 
                     if(*object == NULL || STYPE(*object) != T_UOBJECT) {
-                        err_msg("invalid object name6", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("invalid object name6", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
                 }
@@ -149,7 +149,7 @@ BOOL get_object_prefix_and_name_from_argument(sObject** object, sObject* name, c
                     *object = uobject_item(*object, string_c_str(name));
 
                     if(*object == NULL || STYPE(*object) != T_UOBJECT) {
-                        err_msg("invalid object name7", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("invalid object name7", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
                 }
@@ -164,7 +164,7 @@ BOOL get_object_prefix_and_name_from_argument(sObject** object, sObject* name, c
     }
 
     if(*object == NULL || string_c_str(name) == 0) {
-        err_msg("invalid object name8", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("invalid object name8", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
